#include "champcache.h"

#include "files.h"

#include <QFile>
#include <QFileInfo>
#include <QDateTime>

#include <Log.h>

ChampCache::ChampCache() {
	basefolder = getCache();
}

// the age of f in seconds
static qint64 ageOfFile(QFile& f) {
	QFileInfo info(f);
	return info.lastModified().secsTo(QDateTime::currentDateTime());
}

std::string ChampCache::getVersion() {
	QFile versionfile(QString::fromStdString(basefolder + "version"));
	if(ageOfFile(versionfile) < (qint64) maxage) {
		versionfile.open(QFile::ReadOnly);
		return versionfile.readAll().toStdString();
	}
	return {}; // empty string
}

QJsonDocument ChampCache::getChamps() {
	QFile champsfile(QString::fromStdString(basefolder + "champs.json"));

	if(ageOfFile(champsfile) < (qint64) maxage) {
		champsfile.open(QFile::ReadOnly);
		QByteArray bytes = champsfile.readAll();
		QJsonDocument doc = QJsonDocument::fromJson(bytes);
		return doc;
	}
	return {}; // empty document
}

void ChampCache::saveChamps(QJsonDocument doc, const std::string& version) {
	QByteArray arr = doc.toJson();
	QFile champsfile(QString::fromStdString(basefolder + "champs.json"));
	champsfile.open(QFile::WriteOnly | QFile::Truncate);
	champsfile.write(arr);

	QFile versionfile(QString::fromStdString(basefolder + "version"));
	versionfile.open(QFile::WriteOnly | QFile::Truncate);
	versionfile.write(version.c_str());
	versionfile.close();

	Log::info << "saved Champs and version Cache";
}
