#include "runedisplay.h"
#include "ui_runedisplay.h"

#include <sstream>

const static std::string EMPTY;

RuneDisplay::RuneDisplay(QWidget *parent) : QWidget(parent), ui(new Ui::RuneDisplay) {
	ui->setupUi(this);
}

RuneDisplay::~RuneDisplay() {
	delete ui;
}

void RuneDisplay::setRuneMeta(const std::vector<RuneAspekt>& ri) {
	runeinfo = ri;
}

void RuneDisplay::setStyles(const std::vector<RuneStyle>& styleinfos) {
	runestyles = styleinfos;
}

void RuneDisplay::setRunes(const RunePage& rp) {
	runepage = rp;

	updateText();
}

void RuneDisplay::applyRunesClicked() {
	emit applyRunes();
}

void RuneDisplay::updateText() {
	std::ostringstream out;

	if(! (bool) runepage) {
		ui->runetext->setText(QString::fromStdString(""));
		ui->applyRunesBtn->setEnabled(false);
		return;
	}

	out << getRuneStyleByID(runepage.primaryStyle) << " with " << getRuneStyleByID(runepage.secondaryStyle) << '\n';

	for(uint32_t rune : runepage.selectedAspects) {
		out << getRuneText(rune) << '\n';
	}
	ui->runetext->setText(QString::fromStdString(out.str()));
	ui->applyRunesBtn->setEnabled(true);
}

std::string RuneDisplay::getRuneText(uint32_t id) {
	for(const RuneAspekt& ra : runeinfo) {
		if(ra.id == id) {
			return ra.name;
		}
	}

	return "(" + std::to_string(id) + ")";
}

std::string RuneDisplay::getRuneStyleByID(uint32_t id) {
	auto it = std::find_if(runestyles.begin(), runestyles.end(), [id](const RuneStyle& rs) { return rs.id == id; });
	if(it == runestyles.end()) {
		return '(' + std::to_string(id) + ')';
	}

	return it->name;
}
